Contact Us
##########

For questions related to using Gurobi Model Analyzer please use
`Gurobi's Forum <https://support.gurobi.com/hc/en-us/community/topics/10373864542609-GitHub-Projects>`_.

For reporting bugs, issues and feature request please
`open an issue <https://github.com/Gurobi/gurobi-modelanalyzer/issues>`_.

If you encounter issues with Gurobi or ``gurobipy`` please contact
`Gurobi Support <https://support.gurobi.com/hc/en-us>`_.
